function [Q_gc, Q_evap, T_disch_co2, T_evap, W_compr, V_compr]= ...
    thermodynamics(T_ahe, T_cw, V_ea, T_disch_air)

% Loading constants and parameters:
constants
parameters

Q_rem=hcap_air*(T_ahe-T_disch_air)*V_ea;    % Energy removed from air [Wh]
Q_evap=Q_rem;
LMTD_evap=Q_evap/ua_evap;

% State 1:
t1=(T_disch_air*exp((T_ahe-T_disch_air)/LMTD_evap)-T_ahe)/(exp((T_ahe-T_disch_air)/LMTD_evap)-1);
if t1<-30     % Lower values results in temperature our of range in refprop
    Q_gc=0;
    Q_evap=0;
    T_disch_co2=999;
    T_evap=-99;
    W_compr=0;
    V_compr=0;
    return
end
p1=refpropm('P','T',t1+kelvin,'Q',1,'co2');
h1=refpropm('H','T',t1+kelvin,'Q',1,'co2');
v1_co2=1/refpropm('D','T',t1+kelvin,'Q',1,'co2');
s1=refpropm('S','T',t1+kelvin,'Q',1,'co2');

% State 2:
h2_is=refpropm('H','P',p_gc,'S',s1,'co2');
h2_ad=h1+(h2_is-h1)/eta_is(p_gc,p1);
h2_r=h1+(1-compr_hl)*(h2_ad-h1);
t2=refpropm('T','P',p_gc,'H',h2_r,'co2');

% State 3:
t3=T_cw+ta;
h3=refpropm('H','T',t3+kelvin,'P',p_gc,'co2');

% State 4:
h4=h3;

% Calculating performance and outputs:
m_co2=Q_rem/(h1-h4);                            % Mass flow CO2 [kg/s]
V_compr=m_co2*3600*v1_co2/eta_vol(p_gc,p1);   % Volume flow CO2 [m3/h]
Q_gc=m_co2*(h2_r-h3);                           % Gas cooler energy [Wh]
T_evap=t1;
T_disch_co2=t2;
W_compr=m_co2*(h2_ad-h1)/eta_motor;             % Compressor energy [Wh]